@@ -17,7 +17,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
     .max   <- force(max)
     .i     <- force(initial)
     .killed <- FALSE
-    .showpb <- FALSE
+    ## start showing pb right away when min_time = 0
+    .showpb <- if (min_time > 0)
+        FALSE else TRUE
 
     getVal <- function()  .i
 
@@ -57,9 +59,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
         if (.i > .min && sum(time0, time, na.rm=TRUE) > min_time)
             .showpb <<- TRUE
         if (.showpb) {
-            spentTime <- paste0(" elapsed =", getTimeAsString(time0))
+            spentTime <- paste0(" elapsed=", getTimeAsString(time0))
             leftTime <- if (i == 0)
-                "" else paste0(", remaining ~", getTimeAsString(time))
+                "" else paste0(", remaining~", getTimeAsString(time))
             minLetters <- nchar("%%%% ~00h 00m 00s", "w")
 
             ## 79-24=55 > 50
@@ -69,13 +71,15 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                                           collapse = ""))
-            if(txtWidth < 0)
+            if(txtWidth <= 0) {
                 cat("\r ", text, file = file)
-
-            bb <- paste(rep(char, ceiling(txtWidth * i / n)), collapse = "")
-            empty <- paste(rep(" ", floor(txtWidth * (1 - i / n))), collapse = "")
-            bar <- paste(" |", bb, empty, "|", sep = "")
-            cat(paste("\r", bar, text), file = file)
+            } else {
+                done <- ceiling(txtWidth * i / n)
+                bb <- strrep(char, done)
+                empty <- strrep(" ", txtWidth - done)
+                bar <- paste(" |", bb, empty, "|", sep = "")
+                cat("\r", bar, text, file = file)
+            }
             flush.console()
         }
     }
@@ -94,9 +98,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
         if (.i > .min && sum(time0, time, na.rm=TRUE) > min_time)
             .showpb <<- TRUE
         if (.showpb) {
-            spentTime <- paste0(" elapsed =", getTimeAsString(time0))
+            spentTime <- paste0(" elapsed=", getTimeAsString(time0))
             leftTime <- if (i == 0)
-                "" else paste0(", remaining ~", getTimeAsString(time))
+                "" else paste0(", remaining~", getTimeAsString(time))
             minLetters <- nchar("%%%% ~00h 00m 00s", "w")
 
             ## 79-24=55 > 50
@@ -106,11 +110,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                     collapse = ""))
-            if(txtWidth < 0)
-                cat("\r ", text, file = file)
-            bb <- paste(rep(char, ceiling(txtWidth * i / n)), collapse = "")
+            bb <- strrep(char, ceiling(txtWidth * i / n))
             bar <- c("|", "/", "-", "\\")[(.counter %% 4) + 1]
-            cat(paste("\r", bar, text), file = file)
+            cat("\r", bar, text, file = file)
             flush.console()
         }
     }
@@ -143,12 +145,15 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                     collapse = ""))
-            if(txtWidth < 0)
+            if(txtWidth <= 0) {
                 cat("\r ", text, file = file)
-            bb <- paste(rep(char, ceiling(txtWidth * i / n)), collapse = "")
-            empty <- paste(rep(" ", floor(txtWidth * (1 - i / n))), collapse = "")
-            bar <- paste("  |", bb, empty, "|", sep = "")
-            cat(paste("\r", bar, text), file = file)
+            } else {
+                done <- ceiling(txtWidth * i / n)
+                bb <- strrep(char, done)
+                empty <- strrep(" ", txtWidth - done)
+                bar <- paste(" |", bb, empty, "|", sep = "")
+                cat("\r", bar, text, file = file)
+            }
             flush.console()
         }
     }
@@ -183,11 +188,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                     collapse = ""))
-            if(txtWidth < 0)
-                cat("\r ", text, file = file)
-            bb <- paste(rep(char, ceiling(txtWidth * i / n)), collapse = "")
+            bb <- strrep(char, ceiling(txtWidth * i / n))
             bar <- c("|", "/", "-", "\\")[(.counter %% 4) + 1]
-            cat(paste("\r", bar, text), file = file)
+            cat("\r", bar, text, file = file)
             flush.console()
         }
     }
@@ -204,9 +207,9 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
         if (.i > .min && sum(time0, time, na.rm=TRUE) > min_time)
             .showpb <<- TRUE
         if (.showpb) {
-            spentTime <- paste0(" elapsed =", getTimeAsString(time0))
+            spentTime <- paste0(" elapsed=", getTimeAsString(time0))
             leftTime <- if (i == 0)
-                "" else paste0(", remaining ~", getTimeAsString(time))
+                "" else paste0(", remaining~", getTimeAsString(time))
             minLetters <- nchar("%%%% ~00h 00m 00s", "w")
 
             ## 79-24=55 > 50
@@ -216,13 +219,15 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                                           collapse = ""))
-            if(txtWidth < 0)
+            if(txtWidth <= 0) {
                 cat("\r ", text, file = file)
-
-            bb <- paste(rep(char[2], ceiling(txtWidth * i / n)), collapse = "")
-            empty <- paste(rep(char[3], floor(txtWidth * (1 - i / n))), collapse = "")
-            bar <- paste("  ", char[1], bb, empty, char[4], sep = "")
-            cat(paste("\r", bar, text), file = file)
+            } else {
+                done <- ceiling(txtWidth * i / n)
+                bb <- strrep(char[2], done)
+                empty <- strrep(char[3], txtWidth - done)
+                bar <- paste(" ", char[1], bb, empty, char[4], sep = "")
+                cat("\r", bar, text, file = file)
+            }
             flush.console()
         }
     }
@@ -254,12 +259,15 @@ width = NA, title, label, style = 1, file = "", min_time = 0)
             if(nchar(text, "w") < minLetters)
                 text <- paste(text, paste(rep(" ", minLetters - nchar(text, "w")),
                     collapse = ""))
-            if(txtWidth < 0)
+            if(txtWidth <= 0) {
                 cat("\r ", text, file = file)
-            bb <- paste(rep(char[2], ceiling(txtWidth * i / n)), collapse = "")
-            empty <- paste(rep(char[3], floor(txtWidth * (1 - i / n))), collapse = "")
-            bar <- paste("  ", char[1], bb, empty, char[4], sep = "")
-            cat(paste("\r", bar, text), file = file)
+            } else {
+                done <- ceiling(txtWidth * i / n)
+                bb <- strrep(char[2], done)
+                empty <- strrep(char[3], txtWidth - done)
+                bar <- paste(" ", char[1], bb, empty, char[4], sep = "")
+                cat("\r", bar, text, file = file)
+            }
             flush.console()
         }
     }
@@ -281,6 +289,8 @@ getTimerProgressBar <- getTxtProgressBar
 
 ## converts time in seconds into ~HHh MMm SSs format
 getTimeAsString <- function(time) {
+    if (length(time) > 1L)
+        stop("length of input must be 1")
     if (is.null(time)) {
         return("calculating")
     } else {
